@@ -4,7 +4,7 @@ Main interface for datasync service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_datasync import (
         Client,
         DataSyncClient,
@@ -15,10 +15,8 @@ Usage::
         ListTasksPaginator,
     )
 
-    session = boto3.Session()
-
-    client: DataSyncClient = boto3.client("datasync")
-    session_client: DataSyncClient = session.client("datasync")
+    session = Session()
+    client: DataSyncClient = session.client("datasync")
 
     list_agents_paginator: ListAgentsPaginator = client.get_paginator("list_agents")
     list_locations_paginator: ListLocationsPaginator = client.get_paginator("list_locations")
