@@ -1,7 +1,7 @@
 """
 Type annotations for datasync service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/literals/)
 
 Usage::
 
@@ -58,6 +58,7 @@ __all__ = (
     "ServiceName",
     "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -235,6 +236,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -435,3 +437,26 @@ ResourceServiceName = Literal[
 PaginatorName = Literal[
     "list_agents", "list_locations", "list_tags_for_resource", "list_task_executions", "list_tasks"
 ]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
