@@ -1,7 +1,7 @@
 """
 Type annotations for datasync service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/type_defs/)
 
 Usage::
 
@@ -110,14 +110,19 @@ __all__ = (
     "Ec2ConfigTypeDef",
     "FilterRuleTypeDef",
     "HdfsNameNodeTypeDef",
+    "ListAgentsRequestListAgentsPaginateTypeDef",
     "ListAgentsRequestRequestTypeDef",
     "ListAgentsResponseTypeDef",
+    "ListLocationsRequestListLocationsPaginateTypeDef",
     "ListLocationsRequestRequestTypeDef",
     "ListLocationsResponseTypeDef",
+    "ListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "ListTaskExecutionsRequestListTaskExecutionsPaginateTypeDef",
     "ListTaskExecutionsRequestRequestTypeDef",
     "ListTaskExecutionsResponseTypeDef",
+    "ListTasksRequestListTasksPaginateTypeDef",
     "ListTasksRequestRequestTypeDef",
     "ListTasksResponseTypeDef",
     "LocationFilterTypeDef",
@@ -153,10 +158,11 @@ __all__ = (
 AgentListEntryTypeDef = TypedDict(
     "AgentListEntryTypeDef",
     {
-        "AgentArn": NotRequired[str],
-        "Name": NotRequired[str],
-        "Status": NotRequired[AgentStatusType],
+        "AgentArn": str,
+        "Name": str,
+        "Status": AgentStatusType,
     },
+    total=False,
 )
 
 CancelTaskExecutionRequestRequestTypeDef = TypedDict(
@@ -166,17 +172,30 @@ CancelTaskExecutionRequestRequestTypeDef = TypedDict(
     },
 )
 
-CreateAgentRequestRequestTypeDef = TypedDict(
-    "CreateAgentRequestRequestTypeDef",
+_RequiredCreateAgentRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAgentRequestRequestTypeDef",
     {
         "ActivationKey": str,
-        "AgentName": NotRequired[str],
-        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
-        "VpcEndpointId": NotRequired[str],
-        "SubnetArns": NotRequired[Sequence[str]],
-        "SecurityGroupArns": NotRequired[Sequence[str]],
     },
 )
+_OptionalCreateAgentRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAgentRequestRequestTypeDef",
+    {
+        "AgentName": str,
+        "Tags": Sequence["TagListEntryTypeDef"],
+        "VpcEndpointId": str,
+        "SubnetArns": Sequence[str],
+        "SecurityGroupArns": Sequence[str],
+    },
+    total=False,
+)
+
+
+class CreateAgentRequestRequestTypeDef(
+    _RequiredCreateAgentRequestRequestTypeDef, _OptionalCreateAgentRequestRequestTypeDef
+):
+    pass
+
 
 CreateAgentResponseTypeDef = TypedDict(
     "CreateAgentResponseTypeDef",
@@ -186,15 +205,28 @@ CreateAgentResponseTypeDef = TypedDict(
     },
 )
 
-CreateLocationEfsRequestRequestTypeDef = TypedDict(
-    "CreateLocationEfsRequestRequestTypeDef",
+_RequiredCreateLocationEfsRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLocationEfsRequestRequestTypeDef",
     {
         "EfsFilesystemArn": str,
         "Ec2Config": "Ec2ConfigTypeDef",
-        "Subdirectory": NotRequired[str],
-        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
     },
 )
+_OptionalCreateLocationEfsRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLocationEfsRequestRequestTypeDef",
+    {
+        "Subdirectory": str,
+        "Tags": Sequence["TagListEntryTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateLocationEfsRequestRequestTypeDef(
+    _RequiredCreateLocationEfsRequestRequestTypeDef, _OptionalCreateLocationEfsRequestRequestTypeDef
+):
+    pass
+
 
 CreateLocationEfsResponseTypeDef = TypedDict(
     "CreateLocationEfsResponseTypeDef",
@@ -204,15 +236,29 @@ CreateLocationEfsResponseTypeDef = TypedDict(
     },
 )
 
-CreateLocationFsxLustreRequestRequestTypeDef = TypedDict(
-    "CreateLocationFsxLustreRequestRequestTypeDef",
+_RequiredCreateLocationFsxLustreRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLocationFsxLustreRequestRequestTypeDef",
     {
         "FsxFilesystemArn": str,
         "SecurityGroupArns": Sequence[str],
-        "Subdirectory": NotRequired[str],
-        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
     },
 )
+_OptionalCreateLocationFsxLustreRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLocationFsxLustreRequestRequestTypeDef",
+    {
+        "Subdirectory": str,
+        "Tags": Sequence["TagListEntryTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateLocationFsxLustreRequestRequestTypeDef(
+    _RequiredCreateLocationFsxLustreRequestRequestTypeDef,
+    _OptionalCreateLocationFsxLustreRequestRequestTypeDef,
+):
+    pass
+
 
 CreateLocationFsxLustreResponseTypeDef = TypedDict(
     "CreateLocationFsxLustreResponseTypeDef",
@@ -222,18 +268,32 @@ CreateLocationFsxLustreResponseTypeDef = TypedDict(
     },
 )
 
-CreateLocationFsxWindowsRequestRequestTypeDef = TypedDict(
-    "CreateLocationFsxWindowsRequestRequestTypeDef",
+_RequiredCreateLocationFsxWindowsRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLocationFsxWindowsRequestRequestTypeDef",
     {
         "FsxFilesystemArn": str,
         "SecurityGroupArns": Sequence[str],
         "User": str,
         "Password": str,
-        "Subdirectory": NotRequired[str],
-        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
-        "Domain": NotRequired[str],
     },
 )
+_OptionalCreateLocationFsxWindowsRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLocationFsxWindowsRequestRequestTypeDef",
+    {
+        "Subdirectory": str,
+        "Tags": Sequence["TagListEntryTypeDef"],
+        "Domain": str,
+    },
+    total=False,
+)
+
+
+class CreateLocationFsxWindowsRequestRequestTypeDef(
+    _RequiredCreateLocationFsxWindowsRequestRequestTypeDef,
+    _OptionalCreateLocationFsxWindowsRequestRequestTypeDef,
+):
+    pass
+
 
 CreateLocationFsxWindowsResponseTypeDef = TypedDict(
     "CreateLocationFsxWindowsResponseTypeDef",
@@ -243,24 +303,38 @@ CreateLocationFsxWindowsResponseTypeDef = TypedDict(
     },
 )
 
-CreateLocationHdfsRequestRequestTypeDef = TypedDict(
-    "CreateLocationHdfsRequestRequestTypeDef",
+_RequiredCreateLocationHdfsRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLocationHdfsRequestRequestTypeDef",
     {
         "NameNodes": Sequence["HdfsNameNodeTypeDef"],
         "AuthenticationType": HdfsAuthenticationTypeType,
         "AgentArns": Sequence[str],
-        "Subdirectory": NotRequired[str],
-        "BlockSize": NotRequired[int],
-        "ReplicationFactor": NotRequired[int],
-        "KmsKeyProviderUri": NotRequired[str],
-        "QopConfiguration": NotRequired["QopConfigurationTypeDef"],
-        "SimpleUser": NotRequired[str],
-        "KerberosPrincipal": NotRequired[str],
-        "KerberosKeytab": NotRequired[Union[bytes, IO[bytes], StreamingBody]],
-        "KerberosKrb5Conf": NotRequired[Union[bytes, IO[bytes], StreamingBody]],
-        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
     },
 )
+_OptionalCreateLocationHdfsRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLocationHdfsRequestRequestTypeDef",
+    {
+        "Subdirectory": str,
+        "BlockSize": int,
+        "ReplicationFactor": int,
+        "KmsKeyProviderUri": str,
+        "QopConfiguration": "QopConfigurationTypeDef",
+        "SimpleUser": str,
+        "KerberosPrincipal": str,
+        "KerberosKeytab": Union[bytes, IO[bytes], StreamingBody],
+        "KerberosKrb5Conf": Union[bytes, IO[bytes], StreamingBody],
+        "Tags": Sequence["TagListEntryTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateLocationHdfsRequestRequestTypeDef(
+    _RequiredCreateLocationHdfsRequestRequestTypeDef,
+    _OptionalCreateLocationHdfsRequestRequestTypeDef,
+):
+    pass
+
 
 CreateLocationHdfsResponseTypeDef = TypedDict(
     "CreateLocationHdfsResponseTypeDef",
@@ -270,16 +344,29 @@ CreateLocationHdfsResponseTypeDef = TypedDict(
     },
 )
 
-CreateLocationNfsRequestRequestTypeDef = TypedDict(
-    "CreateLocationNfsRequestRequestTypeDef",
+_RequiredCreateLocationNfsRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLocationNfsRequestRequestTypeDef",
     {
         "Subdirectory": str,
         "ServerHostname": str,
         "OnPremConfig": "OnPremConfigTypeDef",
-        "MountOptions": NotRequired["NfsMountOptionsTypeDef"],
-        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
     },
 )
+_OptionalCreateLocationNfsRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLocationNfsRequestRequestTypeDef",
+    {
+        "MountOptions": "NfsMountOptionsTypeDef",
+        "Tags": Sequence["TagListEntryTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateLocationNfsRequestRequestTypeDef(
+    _RequiredCreateLocationNfsRequestRequestTypeDef, _OptionalCreateLocationNfsRequestRequestTypeDef
+):
+    pass
+
 
 CreateLocationNfsResponseTypeDef = TypedDict(
     "CreateLocationNfsResponseTypeDef",
@@ -289,20 +376,34 @@ CreateLocationNfsResponseTypeDef = TypedDict(
     },
 )
 
-CreateLocationObjectStorageRequestRequestTypeDef = TypedDict(
-    "CreateLocationObjectStorageRequestRequestTypeDef",
+_RequiredCreateLocationObjectStorageRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLocationObjectStorageRequestRequestTypeDef",
     {
         "ServerHostname": str,
         "BucketName": str,
         "AgentArns": Sequence[str],
-        "ServerPort": NotRequired[int],
-        "ServerProtocol": NotRequired[ObjectStorageServerProtocolType],
-        "Subdirectory": NotRequired[str],
-        "AccessKey": NotRequired[str],
-        "SecretKey": NotRequired[str],
-        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
     },
 )
+_OptionalCreateLocationObjectStorageRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLocationObjectStorageRequestRequestTypeDef",
+    {
+        "ServerPort": int,
+        "ServerProtocol": ObjectStorageServerProtocolType,
+        "Subdirectory": str,
+        "AccessKey": str,
+        "SecretKey": str,
+        "Tags": Sequence["TagListEntryTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateLocationObjectStorageRequestRequestTypeDef(
+    _RequiredCreateLocationObjectStorageRequestRequestTypeDef,
+    _OptionalCreateLocationObjectStorageRequestRequestTypeDef,
+):
+    pass
+
 
 CreateLocationObjectStorageResponseTypeDef = TypedDict(
     "CreateLocationObjectStorageResponseTypeDef",
@@ -312,17 +413,30 @@ CreateLocationObjectStorageResponseTypeDef = TypedDict(
     },
 )
 
-CreateLocationS3RequestRequestTypeDef = TypedDict(
-    "CreateLocationS3RequestRequestTypeDef",
+_RequiredCreateLocationS3RequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLocationS3RequestRequestTypeDef",
     {
         "S3BucketArn": str,
         "S3Config": "S3ConfigTypeDef",
-        "Subdirectory": NotRequired[str],
-        "S3StorageClass": NotRequired[S3StorageClassType],
-        "AgentArns": NotRequired[Sequence[str]],
-        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
     },
 )
+_OptionalCreateLocationS3RequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLocationS3RequestRequestTypeDef",
+    {
+        "Subdirectory": str,
+        "S3StorageClass": S3StorageClassType,
+        "AgentArns": Sequence[str],
+        "Tags": Sequence["TagListEntryTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateLocationS3RequestRequestTypeDef(
+    _RequiredCreateLocationS3RequestRequestTypeDef, _OptionalCreateLocationS3RequestRequestTypeDef
+):
+    pass
+
 
 CreateLocationS3ResponseTypeDef = TypedDict(
     "CreateLocationS3ResponseTypeDef",
@@ -332,19 +446,32 @@ CreateLocationS3ResponseTypeDef = TypedDict(
     },
 )
 
-CreateLocationSmbRequestRequestTypeDef = TypedDict(
-    "CreateLocationSmbRequestRequestTypeDef",
+_RequiredCreateLocationSmbRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLocationSmbRequestRequestTypeDef",
     {
         "Subdirectory": str,
         "ServerHostname": str,
         "User": str,
         "Password": str,
         "AgentArns": Sequence[str],
-        "Domain": NotRequired[str],
-        "MountOptions": NotRequired["SmbMountOptionsTypeDef"],
-        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
     },
 )
+_OptionalCreateLocationSmbRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLocationSmbRequestRequestTypeDef",
+    {
+        "Domain": str,
+        "MountOptions": "SmbMountOptionsTypeDef",
+        "Tags": Sequence["TagListEntryTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateLocationSmbRequestRequestTypeDef(
+    _RequiredCreateLocationSmbRequestRequestTypeDef, _OptionalCreateLocationSmbRequestRequestTypeDef
+):
+    pass
+
 
 CreateLocationSmbResponseTypeDef = TypedDict(
     "CreateLocationSmbResponseTypeDef",
@@ -354,20 +481,33 @@ CreateLocationSmbResponseTypeDef = TypedDict(
     },
 )
 
-CreateTaskRequestRequestTypeDef = TypedDict(
-    "CreateTaskRequestRequestTypeDef",
+_RequiredCreateTaskRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateTaskRequestRequestTypeDef",
     {
         "SourceLocationArn": str,
         "DestinationLocationArn": str,
-        "CloudWatchLogGroupArn": NotRequired[str],
-        "Name": NotRequired[str],
-        "Options": NotRequired["OptionsTypeDef"],
-        "Excludes": NotRequired[Sequence["FilterRuleTypeDef"]],
-        "Schedule": NotRequired["TaskScheduleTypeDef"],
-        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
-        "Includes": NotRequired[Sequence["FilterRuleTypeDef"]],
     },
 )
+_OptionalCreateTaskRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateTaskRequestRequestTypeDef",
+    {
+        "CloudWatchLogGroupArn": str,
+        "Name": str,
+        "Options": "OptionsTypeDef",
+        "Excludes": Sequence["FilterRuleTypeDef"],
+        "Schedule": "TaskScheduleTypeDef",
+        "Tags": Sequence["TagListEntryTypeDef"],
+        "Includes": Sequence["FilterRuleTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateTaskRequestRequestTypeDef(
+    _RequiredCreateTaskRequestRequestTypeDef, _OptionalCreateTaskRequestRequestTypeDef
+):
+    pass
+
 
 CreateTaskResponseTypeDef = TypedDict(
     "CreateTaskResponseTypeDef",
@@ -649,9 +789,10 @@ Ec2ConfigTypeDef = TypedDict(
 FilterRuleTypeDef = TypedDict(
     "FilterRuleTypeDef",
     {
-        "FilterType": NotRequired[Literal["SIMPLE_PATTERN"]],
-        "Value": NotRequired[str],
+        "FilterType": Literal["SIMPLE_PATTERN"],
+        "Value": str,
     },
+    total=False,
 )
 
 HdfsNameNodeTypeDef = TypedDict(
@@ -662,12 +803,21 @@ HdfsNameNodeTypeDef = TypedDict(
     },
 )
 
+ListAgentsRequestListAgentsPaginateTypeDef = TypedDict(
+    "ListAgentsRequestListAgentsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListAgentsRequestRequestTypeDef = TypedDict(
     "ListAgentsRequestRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
+        "MaxResults": int,
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListAgentsResponseTypeDef = TypedDict(
@@ -679,13 +829,23 @@ ListAgentsResponseTypeDef = TypedDict(
     },
 )
 
+ListLocationsRequestListLocationsPaginateTypeDef = TypedDict(
+    "ListLocationsRequestListLocationsPaginateTypeDef",
+    {
+        "Filters": Sequence["LocationFilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListLocationsRequestRequestTypeDef = TypedDict(
     "ListLocationsRequestRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
-        "Filters": NotRequired[Sequence["LocationFilterTypeDef"]],
+        "MaxResults": int,
+        "NextToken": str,
+        "Filters": Sequence["LocationFilterTypeDef"],
     },
+    total=False,
 )
 
 ListLocationsResponseTypeDef = TypedDict(
@@ -697,14 +857,50 @@ ListLocationsResponseTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestRequestTypeDef",
+_RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef = TypedDict(
+    "_RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
     {
         "ResourceArn": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef = TypedDict(
+    "_OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListTagsForResourceRequestListTagsForResourcePaginateTypeDef(
+    _RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef,
+    _OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef,
+):
+    pass
+
+
+_RequiredListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "_RequiredListTagsForResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+_OptionalListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "_OptionalListTagsForResourceRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListTagsForResourceRequestRequestTypeDef(
+    _RequiredListTagsForResourceRequestRequestTypeDef,
+    _OptionalListTagsForResourceRequestRequestTypeDef,
+):
+    pass
+
 
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
@@ -715,13 +911,23 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
+ListTaskExecutionsRequestListTaskExecutionsPaginateTypeDef = TypedDict(
+    "ListTaskExecutionsRequestListTaskExecutionsPaginateTypeDef",
+    {
+        "TaskArn": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListTaskExecutionsRequestRequestTypeDef = TypedDict(
     "ListTaskExecutionsRequestRequestTypeDef",
     {
-        "TaskArn": NotRequired[str],
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
+        "TaskArn": str,
+        "MaxResults": int,
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListTaskExecutionsResponseTypeDef = TypedDict(
@@ -733,13 +939,23 @@ ListTaskExecutionsResponseTypeDef = TypedDict(
     },
 )
 
+ListTasksRequestListTasksPaginateTypeDef = TypedDict(
+    "ListTasksRequestListTasksPaginateTypeDef",
+    {
+        "Filters": Sequence["TaskFilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListTasksRequestRequestTypeDef = TypedDict(
     "ListTasksRequestRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
-        "Filters": NotRequired[Sequence["TaskFilterTypeDef"]],
+        "MaxResults": int,
+        "NextToken": str,
+        "Filters": Sequence["TaskFilterTypeDef"],
     },
+    total=False,
 )
 
 ListTasksResponseTypeDef = TypedDict(
@@ -763,16 +979,18 @@ LocationFilterTypeDef = TypedDict(
 LocationListEntryTypeDef = TypedDict(
     "LocationListEntryTypeDef",
     {
-        "LocationArn": NotRequired[str],
-        "LocationUri": NotRequired[str],
+        "LocationArn": str,
+        "LocationUri": str,
     },
+    total=False,
 )
 
 NfsMountOptionsTypeDef = TypedDict(
     "NfsMountOptionsTypeDef",
     {
-        "Version": NotRequired[NfsVersionType],
+        "Version": NfsVersionType,
     },
+    total=False,
 )
 
 OnPremConfigTypeDef = TypedDict(
@@ -785,48 +1003,52 @@ OnPremConfigTypeDef = TypedDict(
 OptionsTypeDef = TypedDict(
     "OptionsTypeDef",
     {
-        "VerifyMode": NotRequired[VerifyModeType],
-        "OverwriteMode": NotRequired[OverwriteModeType],
-        "Atime": NotRequired[AtimeType],
-        "Mtime": NotRequired[MtimeType],
-        "Uid": NotRequired[UidType],
-        "Gid": NotRequired[GidType],
-        "PreserveDeletedFiles": NotRequired[PreserveDeletedFilesType],
-        "PreserveDevices": NotRequired[PreserveDevicesType],
-        "PosixPermissions": NotRequired[PosixPermissionsType],
-        "BytesPerSecond": NotRequired[int],
-        "TaskQueueing": NotRequired[TaskQueueingType],
-        "LogLevel": NotRequired[LogLevelType],
-        "TransferMode": NotRequired[TransferModeType],
-        "SecurityDescriptorCopyFlags": NotRequired[SmbSecurityDescriptorCopyFlagsType],
+        "VerifyMode": VerifyModeType,
+        "OverwriteMode": OverwriteModeType,
+        "Atime": AtimeType,
+        "Mtime": MtimeType,
+        "Uid": UidType,
+        "Gid": GidType,
+        "PreserveDeletedFiles": PreserveDeletedFilesType,
+        "PreserveDevices": PreserveDevicesType,
+        "PosixPermissions": PosixPermissionsType,
+        "BytesPerSecond": int,
+        "TaskQueueing": TaskQueueingType,
+        "LogLevel": LogLevelType,
+        "TransferMode": TransferModeType,
+        "SecurityDescriptorCopyFlags": SmbSecurityDescriptorCopyFlagsType,
     },
+    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 PrivateLinkConfigTypeDef = TypedDict(
     "PrivateLinkConfigTypeDef",
     {
-        "VpcEndpointId": NotRequired[str],
-        "PrivateLinkEndpoint": NotRequired[str],
-        "SubnetArns": NotRequired[List[str]],
-        "SecurityGroupArns": NotRequired[List[str]],
+        "VpcEndpointId": str,
+        "PrivateLinkEndpoint": str,
+        "SubnetArns": List[str],
+        "SecurityGroupArns": List[str],
     },
+    total=False,
 )
 
 QopConfigurationTypeDef = TypedDict(
     "QopConfigurationTypeDef",
     {
-        "RpcProtection": NotRequired[HdfsRpcProtectionType],
-        "DataTransferProtection": NotRequired[HdfsDataTransferProtectionType],
+        "RpcProtection": HdfsRpcProtectionType,
+        "DataTransferProtection": HdfsDataTransferProtectionType,
     },
+    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -850,19 +1072,34 @@ S3ConfigTypeDef = TypedDict(
 SmbMountOptionsTypeDef = TypedDict(
     "SmbMountOptionsTypeDef",
     {
-        "Version": NotRequired[SmbVersionType],
+        "Version": SmbVersionType,
     },
+    total=False,
 )
 
-StartTaskExecutionRequestRequestTypeDef = TypedDict(
-    "StartTaskExecutionRequestRequestTypeDef",
+_RequiredStartTaskExecutionRequestRequestTypeDef = TypedDict(
+    "_RequiredStartTaskExecutionRequestRequestTypeDef",
     {
         "TaskArn": str,
-        "OverrideOptions": NotRequired["OptionsTypeDef"],
-        "Includes": NotRequired[Sequence["FilterRuleTypeDef"]],
-        "Excludes": NotRequired[Sequence["FilterRuleTypeDef"]],
     },
 )
+_OptionalStartTaskExecutionRequestRequestTypeDef = TypedDict(
+    "_OptionalStartTaskExecutionRequestRequestTypeDef",
+    {
+        "OverrideOptions": "OptionsTypeDef",
+        "Includes": Sequence["FilterRuleTypeDef"],
+        "Excludes": Sequence["FilterRuleTypeDef"],
+    },
+    total=False,
+)
+
+
+class StartTaskExecutionRequestRequestTypeDef(
+    _RequiredStartTaskExecutionRequestRequestTypeDef,
+    _OptionalStartTaskExecutionRequestRequestTypeDef,
+):
+    pass
+
 
 StartTaskExecutionResponseTypeDef = TypedDict(
     "StartTaskExecutionResponseTypeDef",
@@ -872,13 +1109,24 @@ StartTaskExecutionResponseTypeDef = TypedDict(
     },
 )
 
-TagListEntryTypeDef = TypedDict(
-    "TagListEntryTypeDef",
+_RequiredTagListEntryTypeDef = TypedDict(
+    "_RequiredTagListEntryTypeDef",
     {
         "Key": str,
-        "Value": NotRequired[str],
     },
 )
+_OptionalTagListEntryTypeDef = TypedDict(
+    "_OptionalTagListEntryTypeDef",
+    {
+        "Value": str,
+    },
+    total=False,
+)
+
+
+class TagListEntryTypeDef(_RequiredTagListEntryTypeDef, _OptionalTagListEntryTypeDef):
+    pass
+
 
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
@@ -891,24 +1139,26 @@ TagResourceRequestRequestTypeDef = TypedDict(
 TaskExecutionListEntryTypeDef = TypedDict(
     "TaskExecutionListEntryTypeDef",
     {
-        "TaskExecutionArn": NotRequired[str],
-        "Status": NotRequired[TaskExecutionStatusType],
+        "TaskExecutionArn": str,
+        "Status": TaskExecutionStatusType,
     },
+    total=False,
 )
 
 TaskExecutionResultDetailTypeDef = TypedDict(
     "TaskExecutionResultDetailTypeDef",
     {
-        "PrepareDuration": NotRequired[int],
-        "PrepareStatus": NotRequired[PhaseStatusType],
-        "TotalDuration": NotRequired[int],
-        "TransferDuration": NotRequired[int],
-        "TransferStatus": NotRequired[PhaseStatusType],
-        "VerifyDuration": NotRequired[int],
-        "VerifyStatus": NotRequired[PhaseStatusType],
-        "ErrorCode": NotRequired[str],
-        "ErrorDetail": NotRequired[str],
+        "PrepareDuration": int,
+        "PrepareStatus": PhaseStatusType,
+        "TotalDuration": int,
+        "TransferDuration": int,
+        "TransferStatus": PhaseStatusType,
+        "VerifyDuration": int,
+        "VerifyStatus": PhaseStatusType,
+        "ErrorCode": str,
+        "ErrorDetail": str,
     },
+    total=False,
 )
 
 TaskFilterTypeDef = TypedDict(
@@ -923,10 +1173,11 @@ TaskFilterTypeDef = TypedDict(
 TaskListEntryTypeDef = TypedDict(
     "TaskListEntryTypeDef",
     {
-        "TaskArn": NotRequired[str],
-        "Status": NotRequired[TaskStatusType],
-        "Name": NotRequired[str],
+        "TaskArn": str,
+        "Status": TaskStatusType,
+        "Name": str,
     },
+    total=False,
 )
 
 TaskScheduleTypeDef = TypedDict(
@@ -944,68 +1195,135 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateAgentRequestRequestTypeDef = TypedDict(
-    "UpdateAgentRequestRequestTypeDef",
+_RequiredUpdateAgentRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateAgentRequestRequestTypeDef",
     {
         "AgentArn": str,
-        "Name": NotRequired[str],
     },
 )
+_OptionalUpdateAgentRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateAgentRequestRequestTypeDef",
+    {
+        "Name": str,
+    },
+    total=False,
+)
 
-UpdateLocationHdfsRequestRequestTypeDef = TypedDict(
-    "UpdateLocationHdfsRequestRequestTypeDef",
+
+class UpdateAgentRequestRequestTypeDef(
+    _RequiredUpdateAgentRequestRequestTypeDef, _OptionalUpdateAgentRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredUpdateLocationHdfsRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateLocationHdfsRequestRequestTypeDef",
     {
         "LocationArn": str,
-        "Subdirectory": NotRequired[str],
-        "NameNodes": NotRequired[Sequence["HdfsNameNodeTypeDef"]],
-        "BlockSize": NotRequired[int],
-        "ReplicationFactor": NotRequired[int],
-        "KmsKeyProviderUri": NotRequired[str],
-        "QopConfiguration": NotRequired["QopConfigurationTypeDef"],
-        "AuthenticationType": NotRequired[HdfsAuthenticationTypeType],
-        "SimpleUser": NotRequired[str],
-        "KerberosPrincipal": NotRequired[str],
-        "KerberosKeytab": NotRequired[Union[bytes, IO[bytes], StreamingBody]],
-        "KerberosKrb5Conf": NotRequired[Union[bytes, IO[bytes], StreamingBody]],
-        "AgentArns": NotRequired[Sequence[str]],
     },
 )
+_OptionalUpdateLocationHdfsRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateLocationHdfsRequestRequestTypeDef",
+    {
+        "Subdirectory": str,
+        "NameNodes": Sequence["HdfsNameNodeTypeDef"],
+        "BlockSize": int,
+        "ReplicationFactor": int,
+        "KmsKeyProviderUri": str,
+        "QopConfiguration": "QopConfigurationTypeDef",
+        "AuthenticationType": HdfsAuthenticationTypeType,
+        "SimpleUser": str,
+        "KerberosPrincipal": str,
+        "KerberosKeytab": Union[bytes, IO[bytes], StreamingBody],
+        "KerberosKrb5Conf": Union[bytes, IO[bytes], StreamingBody],
+        "AgentArns": Sequence[str],
+    },
+    total=False,
+)
 
-UpdateLocationNfsRequestRequestTypeDef = TypedDict(
-    "UpdateLocationNfsRequestRequestTypeDef",
+
+class UpdateLocationHdfsRequestRequestTypeDef(
+    _RequiredUpdateLocationHdfsRequestRequestTypeDef,
+    _OptionalUpdateLocationHdfsRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredUpdateLocationNfsRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateLocationNfsRequestRequestTypeDef",
     {
         "LocationArn": str,
-        "Subdirectory": NotRequired[str],
-        "OnPremConfig": NotRequired["OnPremConfigTypeDef"],
-        "MountOptions": NotRequired["NfsMountOptionsTypeDef"],
     },
 )
+_OptionalUpdateLocationNfsRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateLocationNfsRequestRequestTypeDef",
+    {
+        "Subdirectory": str,
+        "OnPremConfig": "OnPremConfigTypeDef",
+        "MountOptions": "NfsMountOptionsTypeDef",
+    },
+    total=False,
+)
 
-UpdateLocationObjectStorageRequestRequestTypeDef = TypedDict(
-    "UpdateLocationObjectStorageRequestRequestTypeDef",
+
+class UpdateLocationNfsRequestRequestTypeDef(
+    _RequiredUpdateLocationNfsRequestRequestTypeDef, _OptionalUpdateLocationNfsRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredUpdateLocationObjectStorageRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateLocationObjectStorageRequestRequestTypeDef",
     {
         "LocationArn": str,
-        "ServerPort": NotRequired[int],
-        "ServerProtocol": NotRequired[ObjectStorageServerProtocolType],
-        "Subdirectory": NotRequired[str],
-        "AccessKey": NotRequired[str],
-        "SecretKey": NotRequired[str],
-        "AgentArns": NotRequired[Sequence[str]],
     },
 )
+_OptionalUpdateLocationObjectStorageRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateLocationObjectStorageRequestRequestTypeDef",
+    {
+        "ServerPort": int,
+        "ServerProtocol": ObjectStorageServerProtocolType,
+        "Subdirectory": str,
+        "AccessKey": str,
+        "SecretKey": str,
+        "AgentArns": Sequence[str],
+    },
+    total=False,
+)
 
-UpdateLocationSmbRequestRequestTypeDef = TypedDict(
-    "UpdateLocationSmbRequestRequestTypeDef",
+
+class UpdateLocationObjectStorageRequestRequestTypeDef(
+    _RequiredUpdateLocationObjectStorageRequestRequestTypeDef,
+    _OptionalUpdateLocationObjectStorageRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredUpdateLocationSmbRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateLocationSmbRequestRequestTypeDef",
     {
         "LocationArn": str,
-        "Subdirectory": NotRequired[str],
-        "User": NotRequired[str],
-        "Domain": NotRequired[str],
-        "Password": NotRequired[str],
-        "AgentArns": NotRequired[Sequence[str]],
-        "MountOptions": NotRequired["SmbMountOptionsTypeDef"],
     },
 )
+_OptionalUpdateLocationSmbRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateLocationSmbRequestRequestTypeDef",
+    {
+        "Subdirectory": str,
+        "User": str,
+        "Domain": str,
+        "Password": str,
+        "AgentArns": Sequence[str],
+        "MountOptions": "SmbMountOptionsTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateLocationSmbRequestRequestTypeDef(
+    _RequiredUpdateLocationSmbRequestRequestTypeDef, _OptionalUpdateLocationSmbRequestRequestTypeDef
+):
+    pass
+
 
 UpdateTaskExecutionRequestRequestTypeDef = TypedDict(
     "UpdateTaskExecutionRequestRequestTypeDef",
@@ -1015,15 +1333,27 @@ UpdateTaskExecutionRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateTaskRequestRequestTypeDef = TypedDict(
-    "UpdateTaskRequestRequestTypeDef",
+_RequiredUpdateTaskRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateTaskRequestRequestTypeDef",
     {
         "TaskArn": str,
-        "Options": NotRequired["OptionsTypeDef"],
-        "Excludes": NotRequired[Sequence["FilterRuleTypeDef"]],
-        "Schedule": NotRequired["TaskScheduleTypeDef"],
-        "Name": NotRequired[str],
-        "CloudWatchLogGroupArn": NotRequired[str],
-        "Includes": NotRequired[Sequence["FilterRuleTypeDef"]],
     },
 )
+_OptionalUpdateTaskRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateTaskRequestRequestTypeDef",
+    {
+        "Options": "OptionsTypeDef",
+        "Excludes": Sequence["FilterRuleTypeDef"],
+        "Schedule": "TaskScheduleTypeDef",
+        "Name": str,
+        "CloudWatchLogGroupArn": str,
+        "Includes": Sequence["FilterRuleTypeDef"],
+    },
+    total=False,
+)
+
+
+class UpdateTaskRequestRequestTypeDef(
+    _RequiredUpdateTaskRequestRequestTypeDef, _OptionalUpdateTaskRequestRequestTypeDef
+):
+    pass
